Unity Catalog
~~~~~~~~~~~~~
Interface with Unity catalogs.

.. currentmodule:: polars

.. autosummary::
   :toctree: api/

   Catalog
   Catalog.list_catalogs
   Catalog.list_namespaces
   Catalog.list_tables
   Catalog.get_table_info
   Catalog.scan_table
   catalog.unity.CatalogInfo
   catalog.unity.ColumnInfo
   catalog.unity.DataSourceFormat
   catalog.unity.NamespaceInfo
   catalog.unity.TableInfo
   catalog.unity.TableInfo.get_polars_schema
   catalog.unity.TableType
